"""Module with the definition of bismuth liquid metal object class,
i.e., Bismuth"""
from ._constants import BISMUTH_MELTING_TEMPERATURE
from ._constants import BISMUTH_MELTING_LATENT_HEAT
from ._constants import BISMUTH_BOILING_TEMPERATURE
from ._constants import BISMUTH_VAPORISATION_HEAT, P_ATM
from ._lbh15 import LiquidMetalInterface


class Bismuth(LiquidMetalInterface):
    """
    Class to model liquid bismuth properties at a given temperature

    Parameters
    ----------
    p : float, optional
        Pressure in [Pa], by default atmospheric pressure, i.e.,
        101325.0 Pa
    \\**kwargs : dict
        Dictionary that specifies the quantity from which the object shall
        be initialized. The available default ones are:

        - **T** (float) : temperature [K]
        - **p_s** (float) : saturation vapour pressure [Pa]
        - **sigma** (float) : surface tension [N/m]
        - **rho** (float) : density [Kg/m^3]
        - **alpha** (float) : thermal expansion coefficient [1/K]
        - **u_s** (float) : speed of sound [m/s]
        - **beta_s** (float) : isentropic compressibility [1/Pa]
        - **cp** (float) : specific heat capacity [J/(kg*K)]
        - **h** (float) : specific enthalpy \
        (in respect to melting point) [J/kg]
        - **mu** (float) : dynamic viscosity [Pa*s]
        - **r** (float) : electrical resistivity [Ohm*m]
        - **k** (float) : thermal conductivity [W/(m*K)]

    Examples
    --------
    >>> liquid_bismuth = Bismuth(T=670.0)
    >>> liquid_bismuth.k  # [W/(m*K)]
    13.705
    """
    _default_corr_to_use = {}
    _correlations_to_use = {}
    _roots_to_use = {'cp': 0}
    _properties_module = 'lbh15.properties.bismuth_properties'

    def __init__(self, p=P_ATM, **kwargs):
        self._guess = BISMUTH_MELTING_TEMPERATURE*1.5
        super().__init__(p=p, **kwargs)

    def _set_constants(self):
        """
        Sets the class constants
        """
        self._T_m0 = BISMUTH_MELTING_TEMPERATURE
        self._Q_m0 = BISMUTH_MELTING_LATENT_HEAT
        self._T_b0 = BISMUTH_BOILING_TEMPERATURE
        self._Q_b0 = BISMUTH_VAPORISATION_HEAT



#!/usr/bin/python3

from setuptools import setup
from setuptools import find_packages
from lbh15 import __version__
from lbh15 import __author__

setup(
    name='lbh15',
    version=__version__,
    packages=find_packages(),
    include_package_data=True,
    author=__author__,
    author_email='daniele.panico@newcleo.com, daniele.tomatis@newcleo.com',
    description='Python implementation of liquid metal properties from '
                'Handbook on Lead-bismuth Eutectic Alloy and Lead Properties, '
                'Materials Compatibility, Thermal-hydraulics and Technologies',
    long_description_content_type='text/x-rst',
    long_description=open('README.rst', 'r').read(),
    license='lgpl v3',
    python_requires='>=3.8.10',
    install_requires=['scipy>=1.8.1', 'numpy>=1.22.3'],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Education",
        "Intended Audience :: Science/Research",
        "License :: OSI Approved :: GNU Lesser General Public License v3 (LGPLv3)",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python",
        "Topic :: Scientific/Engineering",
        "Topic :: Scientific/Engineering :: Physics",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
)

"""
Developers memo:
    - how to upload on PyPI:
        python3 setup.py sdist                     # in project directory
        twine check dist/*                         # check that package is ok
        twine upload --repository testpypi dist/*  # verify upload is successful on test-PyPI (see note below)
        twine upload dist/*                        # upload to PyPI: upload fails if version is already on PyPI

    - how to test package installation from test-pypi:
        - upload the new version of the package but change the package name in setup.py in lbh15_test
        - install the package from test-pypi using the following command:
            pip install --index-url https://test.pypi.org/simple/ --extra-index-url https://pypi.org/simple lbh15_test
"""